'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

require('./modules/styles/reset.scss');

require('./modules/styles/common.scss');

var _utils = require('./modules/utils');

var _utils2 = _interopRequireDefault(_utils);

var _toast = require('./modules/toast');

var _toast2 = _interopRequireDefault(_toast);

var _loading = require('./modules/loading');

var _loading2 = _interopRequireDefault(_loading);

var _dialog = require('./modules/dialog');

var _dialog2 = _interopRequireDefault(_dialog);

var _event = require('./modules/event');

var _event2 = _interopRequireDefault(_event);

var _fetch = require('./modules/fetch');

var _fetch2 = _interopRequireDefault(_fetch);

var _monitor = require('./modules/monitor');

var _monitor2 = _interopRequireDefault(_monitor);

var _commonStatus = require('./modules/common-status');

var _commonStatus2 = _interopRequireDefault(_commonStatus);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isLoaded = false,
    // 是否已经回调onload
isBinded = false,
    needCallBind = false,
    // 是否需要调用onbind，当platformBindFinish在onLoad之前被调用时此值被置为true
xmkit = void 0;

if (window.xmkit) {
    //console.error('xmkit重复初始化！');
    xmkit = window.xmkit;
} else {
    var XmKit = function XmKit(config) {};

    /**
     * 页面初始化
     * @param {*object} config 页面配置
     * {
     *      title: '', // 页面标题，统计用
     *      debug: true, // 是否开启调试
     *      loaded: function, // window onLoad回调
     *      binded: function, // jsbridge绑定成功回调
     *      phead: phead, // phead
     *      monitor: false, // 开启监控，默认false
     * }
     */
    XmKit.prototype.init = function (config) {
        // 这种方式在某些情况会导致出错
        // this.config = Object.assign({
        //     title: 'miss title',
        //     debug: false,
        //     loaded: function(){},
        //     binded: function(){},
        //     monitor: false,
        //     phead: {"pversion":"30","cversion":0,"cityid":"440100","gcityid":"440100"}
        // }, config);

        this.config = {
            title: 'miss title',
            debug: false,
            loaded: function loaded() {},
            binded: function binded() {},
            monitor: false,
            phead: {
                "pversion": "30",
                "cversion": 0,
                "cityid": "440100",
                "gcityid": "440100"
            }
        };

        if (config) {
            if (config.title !== undefined) {
                this.config.title = config.title;
            }
            if (config.debug !== undefined) {
                this.config.debug = config.debug;
            }
            if (config.loaded !== undefined) {
                this.config.loaded = config.loaded;
                if (isLoaded) {
                    config.loaded();
                }
            }
            if (config.binded !== undefined) {
                this.config.binded = config.binded;
                if (isBinded) {
                    config.binded();
                }
            }
            if (config.monitor !== undefined) {
                this.config.monitor = config.monitor;
            }
            if (config.phead !== undefined) {
                this.config.phead = config.phead;
            }
        }

        this.log('XmKit init...' + this.config.title);
        _utils2.default.mount(XmKit);
        _toast2.default.mount(XmKit);
        _loading2.default.mount(XmKit);
        _dialog2.default.mount(XmKit);
        _event2.default.mount(XmKit);
        _fetch2.default.mount(XmKit, this.config.phead);
        _commonStatus2.default.mount(XmKit);
        this.config.monitor && _monitor2.default.mount(XmKit, this.config.title);

        this.log('XmKit init finish');
    };

    XmKit.prototype.loaded = function () {
        this.log('XmKit loaded');
        this.config.loaded();
        this.config.monitor && _monitor2.default.bindPerformanceTimingMonitor();
    };

    XmKit.prototype.binded = function () {
        this.log('XmKit binded');
        this.config.binded();
    };

    XmKit.prototype.log = function (msg) {
        this.config && this.config.debug && console.log(msg);
    };

    XmKit.prototype.updatePhead = function (phead) {
        this.config.phead = phead;
        _fetch2.default.updatePhead(phead);
    };

    xmkit = new XmKit({});

    window.xmkit = xmkit;
}

window.platformBindFinish = function () {
    if (isLoaded) {
        isBinded = true;
        xmkit.binded && xmkit.binded();
    } else {
        needCallBind = true;
    }
};
window.addEventListener('load', function () {
    isLoaded = true;
    xmkit.loaded && xmkit.loaded();
    if (_utils2.default.isAndroid() || needCallBind) {
        isBinded = true;
        xmkit.binded && xmkit.binded();
    }
});

exports.default = xmkit;