'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _loading = require('./loading');

var _loading2 = _interopRequireDefault(_loading);

var _toast = require('./toast');

var _toast2 = _interopRequireDefault(_toast);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _phead = void 0;

/**
 * 发起请求
 * 
 * @param {*object} config 
 * {
 *      service     服务名
 *      path        路径，默认为common
 *      funid       接口号
 *      url         如果是特殊url，直接指定即可
 *      data        post的数据
 *      showLoading 是否展示loading浮层
 *      beforeSend  请求前回调
 *      callback    请求成功回调
 *      failCallback 请求成功但是服务器出错
 *      onError     请求发生错误回调
 *      complete    请求完成回调
 *      ignoreError 忽略服务器下发的错误状态
 * }
 */
var request = function request(config) {
    var url = void 0,
        postData = void 0,
        paramData = void 0,
        displayLoading = true; // 是否展示loading

    paramData = {
        phead: _phead,
        ispage: 1
    };
    url = config.url || location.origin + '/' + config.service + '/common?funid=' + config.funid + '&rd=' + new Date().getTime();
    postData = {
        data: _extends(paramData, config.data),
        shandle: 0,
        handle: 0
    };

    if (config['showLoading'] === false) {
        displayLoading = false;
    }

    displayLoading && _loading2.default.showLoading();
    $.ajax({
        type: "post",
        timeout: 30000,
        url: url,
        data: JSON.stringify(postData),
        async: true,
        dataType: "json",
        contentType: "application/json",
        beforeSend: function beforeSend() {
            config.beforeSend && config.beforeSend();
        },
        success: function success(data) {
            if (data.result && data.result.status === 1) {
                config.callback && config.callback(data);
            } else {
                config.failCallback && config.failCallback();
                if (!config.ignoreError) {
                    _toast2.default.toast(data.result && data.result.msg);
                }
            }
        },
        error: function error(xhr, status, errorThrown) {
            config.onError && config.onError(errorThrown);
            if (!config.ignoreError) {
                _toast2.default.toast("出错了");
            }
        },
        complete: function complete(xhr, status) {
            config.complete && config.complete();
            displayLoading && _loading2.default.hideLoading();
        }
    });
};

var mount = function mount(xm, phead) {
    _phead = phead;
    xm.prototype.request = request;
};

var updatePhead = function updatePhead(phead) {
    _phead = phead;
};

exports.default = {
    mount: mount,
    updatePhead: updatePhead,
    request: request
};